function [M,Slist,Ilist]=SIRS(N,beta,g,mu,eps,ss,ii)
% Produce a matrix (Q transposed), a list of numbers susceptible, and a
% list of numbers infectious for SIRS dynamics

if nargin < 7
    error('Incorrect number of arguments, SIR_Spacing(N,R0,g,mu,eps,ss,ii)');
end
 
ms=ss(1); Ms=ss(end);  mi=ii(1); Mi=ii(end);

[SS,II]=meshgrid(ms:Ms,mi:Mi);

ls=1+Ms-ms; li=1+Mi-mi;

OK=sign(SS+II-(N+0.5));
OK= (1-OK)/2; 

V=reshape(cumsum(reshape(OK,li*ls,1)),li,ls).*OK;  

SIZE=ls*li;  

From=zeros(5*SIZE,1); To=From; Rate=From;

i=reshape(II,SIZE,1);  s=reshape(SS,SIZE,1);
From(1:SIZE)=reshape(V,SIZE,1); To(1:SIZE)=From(1:SIZE);  
Rate(1:SIZE)=-(mu*(N-i-s) + g*i + s.*(beta*i + eps));
            
q=(li-1)*(ls-1);
i=reshape(II(1:(li-1),1:(ls-1)),q,1); s=reshape(SS(1:(li-1),1:(ls-1)),q,1); 
From(SIZE+(1:q))=reshape(V(1:(li-1),1:(ls-1)),q,1); 
To(SIZE+(1:q))=reshape(V(1:(li-1),2:ls),q,1); 
Rate(SIZE+(1:q))=mu*(N-i-s);

q=SIZE-ls;
i=reshape(II(2:li,1:ls),q,1); 
From(2*SIZE+(1:q))=reshape(V(2:li,1:ls),q,1); 
To(2*SIZE+(1:q))=reshape(V(1:(li-1),1:ls),q,1); 
Rate(2*SIZE+(1:q))=(g)*i;

q=(li-1)*(ls-1);
i=reshape(II(1:(li-1),2:ls),q,1);  s=reshape(SS(1:(li-1),2:ls),q,1); 
From(3*SIZE+(1:q))=reshape(V(1:(li-1),2:ls),q,1); 
To(3*SIZE+(1:q))=reshape(V(2:li,1:(ls-1)),q,1); 
Rate(3*SIZE+(1:q))=s.*(beta*i+eps);
      
Slist=reshape(SS,SIZE,1); Ilist=reshape(II,SIZE,1);
Slist=Slist(logical(OK)); 
Ilist=Ilist(logical(OK)); 
L=length(Ilist);

pos=find(To.*From.*Rate~=0);
M=sparse(To(pos),From(pos),Rate(pos),L,L);

end






