% Script to produce supplementary figure on critical alpha values

clear

% Ranges of model parameters
Nrange = 2:10;
beta_range = [0.5 1:10];
mu_range = [0, 1e-6, 1e-1, 1, 10, Inf];
g = 1;

alpha = zeros(length(Nrange),length(beta_range),length(mu_range));

for ni = 1:length(Nrange)
    N = Nrange(ni);
    for bi = 1:length(beta_range);
        beta = beta_range(bi);
        for mi = 1:length(mu_range)
            mu = mu_range(mi);
            if mu == Inf
                M = SIS(N,beta/(N-1),g,0,[0 N]);
                ii=(0:N)';
                Cind = find(ii>0);
                Iind = 1;
            else
                [M,ss,ii] = SIRS(N,beta/(N-1),g,mu,0,[0 N],[0 N]);
                Cind = find(ii>0);
                Iind = find(Cind==find(ii==1 & ss==(N-1)));
            end
            Qc = full(M(Cind,Cind))';
            f = -ii(Cind);
            z = Qc\f;
            Rstar = z(Iind);
            alpha(ni,bi,mi) = 1/(Rstar);
        end
    end
end

figure(1)
clf
for mi=1:length(mu_range)
    subplot(2,ceil(0.5*length(mu_range)),mi)
    hold on
    for ni=1:length(Nrange)
        i=Nrange(ni);
        for bi=1:length(beta_range)
            patch([i-0.4 i+0.4 i+0.4 i-0.4 i-0.4],[bi bi bi+1 bi+1 bi]-0.5,alpha(ni,bi,mi));
        end
    end
    hold off
    set(gca,'XTick',Nrange,'YTick',1:length(beta_range),'YTickLabel',beta_range,'FontSize',12);%,beta_range,'FontSize',12);
    xlim([min(Nrange)-1, max(Nrange)+1])
    ylim([0, length(beta_range)+1])
    if mu_range(mi) == 0
        title('\mu = 0 (SIR)')
    elseif mu_range(mi) == Inf
        title('\mu = \infty (SIS)')
    else
        title(['\mu = ' num2str(mu_range(mi))])
    end
    xlabel('N')
    ylabel('\beta')
    colorbar
    caxis([0 max(max(max(alpha)))])
end
